const path = require('path')
const nodeExternals = require('webpack-node-externals');
const HtmlWebpackPlugin = require('html-webpack-plugin');
// const miniCssExtractPlugin = require('mini-css-extract-plugin');
const FriendlyErrorsWebpackPlugin = require('friendly-errors-webpack-plugin');
const ReactRefreshTypeScript = require('react-refresh-typescript');
const webpack = require('webpack');
const ReactRefreshPlugin = require('@pmmmwh/react-refresh-webpack-plugin')
const projectRoot = process.cwd();

module.exports.webpackConfig = {
  entry: {
    main: ['./app/pages/index.tsx']
  },
  // css: {
  //   extract: false
  // },
  mode: 'development',
  devtool: 'cheap-module-eval-source-map',
  output: {
    path: path.resolve(projectRoot, './app/public'),
    filename: 'js/[name].js',
    publicPath: '/'
  },
  // target: 'node',
  // externals: [nodeExternals()], 
  module: {
    rules: [
      {
        test: /\.tsx?/,
        loader: 'ts-loader',
        options: {
          // disable type checker - we will use it in fork plugin
          transpileOnly: true,
        },
      },
      {
        test: /\.css$/,
        use: ['style-loader', {
          loader: 'css-loader',
          options: {
            // modules: true
          }
        }]
      },
      // {
      //   test: /\.css$/,
      //   use: [miniCssExtractPlugin.loader, 'css-loader', {
      //     loader: 'postcss-loader',
      //     options: {
      //       plugins: () => [require('autoprefixer')],
      //       extract: false
      //     }
      //   }]
      // },
      // {
      //   test: /\.less$/,
      //   use: [miniCssExtractPlugin.loader, 'css-loader', {
      //     loader: "postcss-loader",
      //     options: {
      //       plugins: () => [require('autoprefixer')],
      //       extract: false
      //     }
      //   }, 'less-loader']
      // },
      {
        test: /\.(woff|woff2|eot|ttf|otf|svg)$/,
        use: [
          'file-loader'
        ]
      },
      {
        test: /\.(png|gif|jpg|jpeg)$/,
        use: [
          'file-loader'
        ]
      },
      {
        test: /\.less$/,
        use: [
          require.resolve('style-loader'),
          {
            loader: require.resolve('css-loader')
          },
          {
            loader: require.resolve('less-loader'), // compiles Less to CSS
          },
          {
            loader: require.resolve('sass-resources-loader'),
            options: {
              resources: path.resolve(projectRoot, './app/pages/var.less')
            }
          }
        ],
      },
      // {
      //   test: /\.less$/,
      //   use: ['style-loader', 'css-loader', 'less-loader']
      // }
    ]
  },
  plugins: [
    // new miniCssExtractPlugin({
    //   filename: "css/[name].css",////都提到build目录下的css目录中
    //   chunkFilename: "[id].css"
    // }),
    new HtmlWebpackPlugin({ // 打包输出HTML
      title: 'Hello World app',
      minify: { // 压缩HTML文件
        removeComments: true, // 移除HTML中的注释
        collapseWhitespace: true, // 删除空白符与换行符
        minifyCSS: true// 压缩内联css
      },
      filename: 'index.html',
      template: './app/pages/index.html',
      chunks: ['main']
    }),
    new FriendlyErrorsWebpackPlugin(),
    new webpack.HotModuleReplacementPlugin(),
    new ReactRefreshPlugin({
      exclude: [/node_modules/],
    }),

  ],
  stats: 'errors-only',
  resolve: {
    extensions: ['.js', '.ts', '.tsx'],
    alias: {
      '@': path.join(projectRoot, './app/pages')
    },
  }
}