// const config = require('./index');
const path = require('path');
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const ReactRefreshPlugin = require('@pmmmwh/react-refresh-webpack-plugin')
const projectRoot = process.cwd();

module.exports = (config) => {
  return {
    entry: {
      [config.packageName]: `./src/index.ts${config.fix}`
    },
    output: {
      path: path.join(__dirname, '../dist'),
      filename: '[name].js'
    },
    mode: 'development',
    devtool: 'cheap-module-source-map',
    plugins: [
      new HtmlWebpackPlugin({
        template: path.join(projectRoot, './src/index.html'),
        filename: 'index.html',
        chunks: [config.packageName],
        inject: true,
        minify: {
          html5: true,
          collapseWhitespace: true,
          preserveLineBreaks: true,
          minifyCSS: true,
          minifyJS: true,
          removeComments: true
        }
      }),
      new webpack.HotModuleReplacementPlugin(),
      new ReactRefreshPlugin({
        exclude: [/node_modules/],
      }),
    ],
    devServer: {
      contentBase: './dist',
      hot: true,
      historyApiFallback: config.historyApiFallback,
      stats: 'errors-only'
    }
  }
}