const path = require('path')
const nodeExternals = require('webpack-node-externals');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const miniCssExtractPlugin = require('mini-css-extract-plugin');
const webpack = require('webpack');
const projectRoot = process.cwd();

module.exports.webpackConfig = {
  entry: {
    main: ['./src/pages/index.tsx']
  },
  // css: {
  //   extract: false
  // },
  mode: 'development',
  output: {
    path: path.resolve(projectRoot, './src/public'),
    filename: 'js/[name].js',
    publicPath: '/'
  },
  // target: 'node',
  // externals: [nodeExternals()], 
  module: {
    rules: [
      {
        test: /\.tsx?/,
        loader: 'ts-loader'
      },
      // {
      //   test: /\.css$/,
      //   use: ['style-loader', {
      //     loader: 'css-loader',
      //     options: {
      //       modules: true
      //     }
      //   }]
      // },
      {
        test: /\.css$/,
        use: [miniCssExtractPlugin.loader, 'css-loader', {
          loader: 'postcss-loader',
          options: {
            plugins: () => [require('autoprefixer')],
            extract: false
          }
        }]
      },
      {
        test: /\.less$/,
        use: [miniCssExtractPlugin.loader, 'css-loader', {
          loader: "postcss-loader",
          options: {
            plugins: () => [require('autoprefixer')],
            extract: false
          }
        }, 'less-loader']
      },
      {
        test: /\.(woff|woff2|eot|ttf|otf|svg)$/,
        use: [
          'file-loader'
        ]
      }
      // {
      //   test: /\.less$/,
      //   use: ['style-loader', 'css-loader', 'less-loader']
      // }
    ]
  },
  plugins: [
    new miniCssExtractPlugin({
      filename: "css/[name].css",////都提到build目录下的css目录中
      chunkFilename: "[id].css"
    }),
    new HtmlWebpackPlugin({ // 打包输出HTML
      title: 'Hello World app',
      minify: { // 压缩HTML文件
        removeComments: true, // 移除HTML中的注释
        collapseWhitespace: true, // 删除空白符与换行符
        minifyCSS: true// 压缩内联css
      },
      filename: 'index.html',
      template: './src/pages/index.html',
      chunks: ['main']
    })
  ],
  resolve: {
    extensions: ['.js', '.ts', '.tsx']
  },
  devServer: {
    hot: true,
    // historyApiFallback: true,
    // progressColors: true,
    // contentBase: './src/public',
    hotOnly: true,
    port: 4006,
    open: true,
    proxy: {
      '\/?': {
        target: 'http://127.0.0.1:4007',
        secure: false,
        changeOrigin: true
      }
    }
  }
}

module.exports.nodemonConfig = {
  script: path.resolve(projectRoot, './src/index.ts'),
  "restartable": "rs", 
  "watch": [path.resolve(projectRoot, './src'), "../nodemon.json"],
  "ext": "ts tsx json",
  "verbose": true,
  "execMap": {
    "": "node",
    "js": "node --harmony"
  },
  "env": {
    "NODE_ENV": "development"
  }
}