const path = require('path')
const HtmlWebpackPlugin = require('html-webpack-plugin');
const miniCssExtractPlugin = require('mini-css-extract-plugin');
const projectRoot = process.cwd();

module.exports.webpackConfig = {
  entry: {
    main: ['./app/pages/index.tsx']
  },
  mode: 'development',
  output: {
    path: path.resolve(projectRoot, './app/public'),
    filename: 'js/[name].js',
    publicPath: '/'
  },
  module: {
    rules: [
      {
        test: /\.tsx?/,
        loader: 'ts-loader'
      },
      {
        test: /\.css$/,
        use: [miniCssExtractPlugin.loader, 'css-loader', {
          loader: 'postcss-loader',
          options: {
            plugins: () => [require('autoprefixer')],
            extract: false
          }
        }]
      },
      {
        test: /\.less$/,
        use: [miniCssExtractPlugin.loader, 'css-loader', {
          loader: "postcss-loader",
          options: {
            plugins: () => [require('autoprefixer')],
            extract: false
          }
        }, 'less-loader']
      },
      {
        test: /\.(woff|woff2|eot|ttf|otf|svg)$/,
        use: [
          'file-loader'
        ]
      }
    ]
  },
  plugins: [
    new miniCssExtractPlugin({
      filename: "css/[name].css",////都提到build目录下的css目录中
      chunkFilename: "[id].css"
    }),
    new HtmlWebpackPlugin({ // 打包输出HTML
      title: 'Hello World app',
      minify: { // 压缩HTML文件
        removeComments: true, // 移除HTML中的注释
        collapseWhitespace: true, // 删除空白符与换行符
        minifyCSS: true// 压缩内联css
      },
      filename: 'index.html',
      template: './app/pages/index.html',
      chunks: ['main']
    })
  ],
  resolve: {
    extensions: ['.js', '.ts', '.tsx']
  }
}

module.exports.nodemonConfig = {
  script: path.join(projectRoot, './app/server/master.ts'),
    "watch": [path.resolve(projectRoot, './app')],
    "restartable": "rs", 
    "ext": "ts tsx json",
    "verbose": true,
    "exec": "ts-node --files",
    "execMap": {
      "": "node",
      "js": "node --harmony"
    },
    "env": {
      "NODE_ENV": "development"
    },
    "ignore": [
      "package.json",
      "nodemon.json",
      "public/*",
      "node_modules/**/node_modules",
      ".git",
      "typings"
    ]
}