const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const miniCssExtractPlugin = require('mini-css-extract-plugin');
const FriendlyErrorsWebpackPlugin = require('friendly-errors-webpack-plugin');
const projectRoot = process.cwd();

module.exports.webpackProdConfig = {
    entry: {
      main: ['./app/pages/index.tsx']
    },
    mode: 'production',
    output: {
      path: path.resolve(projectRoot, './package/public'),
      filename: 'js/[name].js',
      publicPath: '/'
    },
    stats: 'errors-only',
    // target: 'node',
    // externals: [nodeExternals()], 
    module: {
      rules: [
        {
          test: /\.tsx?/,
          loader: 'ts-loader'
        },
        {
          test: /\.css$/,
          use: [miniCssExtractPlugin.loader, 'css-loader', {
            loader: 'postcss-loader',
            options: {
              plugins: () => [require('autoprefixer')],
              extract: false
            }
          }]
        },
        {
          test: /\.less$/,
          use: [miniCssExtractPlugin.loader, 'css-loader', {
            loader: "postcss-loader",
            options: {
              plugins: () => [require('autoprefixer')],
              extract: false
            }
          }, 'less-loader', {
            loader: "sass-resources-loader",
            options: {
              resources: path.resolve(projectRoot, './app/pages/var.less') 
            }
          }]
        },
        {
          test: /\.(png|gif|jpg|jpeg)$/,
          use: [
            'file-loader'
          ]
        },
        {
          test: /\.(woff|woff2|eot|ttf|otf|svg)$/,
          use: [
            'file-loader'
          ]
        }
        // {
        //   test: /\.less$/,
        //   use: ['style-loader', 'css-loader', 'less-loader']
        // }
      ]
    },
    plugins: [
      new miniCssExtractPlugin({
        filename: "css/[name].css",////都提到build目录下的css目录中
        chunkFilename: "[id].css"
      }),
      new HtmlWebpackPlugin({ // 打包输出HTML
        title: 'XIOO',
        minify: { // 压缩HTML文件
          removeComments: true, // 移除HTML中的注释
          collapseWhitespace: true, // 删除空白符与换行符
          minifyCSS: true// 压缩内联css
        },
        filename: 'index.html',
        template: './app/pages/index.html',
        chunks: ['main']
      }),
      new FriendlyErrorsWebpackPlugin()
    ],
    resolve: {
      extensions: ['.js', '.ts', '.tsx'],
      alias: {
        '@': path.join(projectRoot, './app/pages')
      }
    }
  }